@@ -28,10 +28,10 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
+#include <gio/gio.h>
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <gconf/gconf-client.h>
 
 #include "gnome-settings-plugin-info.h"
 #include "gnome-settings-manager.h"
@@ -40,7 +40,7 @@
 
 #define GSD_MANAGER_DBUS_PATH "/org/gnome/SettingsDaemon"
 
-#define DEFAULT_SETTINGS_PREFIX "/apps/gnome_settings_daemon/plugins"
+#define DEFAULT_SETTINGS_PREFIX "org.gnome.settings-daemon"
 
 #define PLUGIN_EXT ".gnome-settings-plugin"
 
@@ -49,15 +49,10 @@
 struct GnomeSettingsManagerPrivate
 {
         DBusGConnection            *connection;
-        char                       *settings_prefix;
+        GSettings                  *settings;
         GSList                     *plugins;
 };
 
-enum {
-        PROP_0,
-        PROP_SETTINGS_PREFIX,
-};
-
 enum {
         PLUGIN_ACTIVATED,
         PLUGIN_DEACTIVATED,
@@ -151,74 +146,77 @@ on_plugin_deactivated (GnomeSettingsPluginInfo *info,
         g_signal_emit (manager, signals [PLUGIN_DEACTIVATED], 0, name);
 }
 
+static gboolean
+contained (const char * const *items,
+           const char         *item)
+{
+        while (*items) {
+                if (g_strcmp0 (*items++, item) == 0) {
+                        return TRUE;
+                }
+        }
+
+        return FALSE;
+}
+
+static gboolean
+is_schema (const char *schema)
+{
+        return contained (g_settings_list_schemas (), schema);
+}
+
+
 static void
 _load_file (GnomeSettingsManager *manager,
             const char           *filename)
 {
         GnomeSettingsPluginInfo *info;
         char                    *key_name;
-        GConfClient             *client;
-        int                      priority;
-        GError                  *error;
         GSList                  *l;
 
         g_debug ("Loading plugin: %s", filename);
-        gnome_settings_profile_start (NULL);
+        gnome_settings_profile_start ("%s", filename);
 
         info = gnome_settings_plugin_info_new_from_file (filename);
         if (info == NULL) {
                 goto out;
         }
 
-        gnome_settings_profile_start ("seeing if already loaded");
         l = g_slist_find_custom (manager->priv->plugins,
                                  info,
                                  (GCompareFunc) compare_location);
-        gnome_settings_profile_end ("seeing if already loaded");
         if (l != NULL) {
                 goto out;
         }
 
-        manager->priv->plugins = g_slist_prepend (manager->priv->plugins,
-                                                  g_object_ref (info));
-
-        g_signal_connect (info, "activated",
-                          G_CALLBACK (on_plugin_activated), manager);
-        g_signal_connect (info, "deactivated",
-                          G_CALLBACK (on_plugin_deactivated), manager);
-
-        gnome_settings_profile_start ("setting active property");
-        key_name = g_strdup_printf ("%s/%s/active",
-                                    manager->priv->settings_prefix,
+        key_name = g_strdup_printf ("%s.plugins.%s",
+                                    DEFAULT_SETTINGS_PREFIX,
                                     gnome_settings_plugin_info_get_location (info));
-        gnome_settings_plugin_info_set_enabled_key_name (info, key_name);
-        g_free (key_name);
-        gnome_settings_profile_end ("setting active property");
 
-        gnome_settings_profile_start ("setting priority property");
-        key_name = g_strdup_printf ("%s/%s/priority",
-                                    manager->priv->settings_prefix,
-                                    gnome_settings_plugin_info_get_location (info));
-        client = gconf_client_get_default ();
-        error = NULL;
-        priority = gconf_client_get_int (client, key_name, &error);
-        if (error == NULL) {
-                if (priority > 0) {
-                        gnome_settings_plugin_info_set_priority (info, priority);
-                }
+        /* Ignore unknown schemas or else we'll assert */
+        if (is_schema (key_name)) {
+                manager->priv->plugins = g_slist_prepend (manager->priv->plugins,
+                                                          g_object_ref (info));
+
+                g_signal_connect (info, "activated",
+                                  G_CALLBACK (on_plugin_activated), manager);
+                g_signal_connect (info, "deactivated",
+                                  G_CALLBACK (on_plugin_deactivated), manager);
+
+                gnome_settings_plugin_info_set_settings_prefix (info, key_name);
         } else {
-                g_error_free (error);
+                g_warning ("Ignoring unknown module '%s'", key_name);
         }
+
+        /* Priority is set in the call above */
         g_free (key_name);
-        g_object_unref (client);
-        gnome_settings_profile_end ("setting priority property");
 
  out:
         if (info != NULL) {
                 g_object_unref (info);
         }
 
-        gnome_settings_profile_end (NULL);
+        gnome_settings_profile_end ("%s", filename);
 }
 
 static void
@@ -235,7 +233,7 @@ _load_dir (GnomeSettingsManager *manager,
         error = NULL;
         d = g_dir_open (path, 0, &error);
         if (d == NULL) {
-                g_warning (error->message);
+                g_warning ("%s", error->message);
                 g_error_free (error);
                 return;
         }
@@ -272,10 +270,19 @@ _load_all (GnomeSettingsManager *manager)
         gnome_settings_profile_end (NULL);
 }
 
+static void
+_unload_plugin (GnomeSettingsPluginInfo *info, gpointer user_data)
+{
+        if (gnome_settings_plugin_info_get_enabled (info)) {
+                gnome_settings_plugin_info_deactivate (info);
+        }
+        g_object_unref (info);
+}
+
 static void
 _unload_all (GnomeSettingsManager *manager)
 {
-         g_slist_foreach (manager->priv->plugins, (GFunc) g_object_unref, NULL);
+         g_slist_foreach (manager->priv->plugins, (GFunc) _unload_plugin, NULL);
          g_slist_free (manager->priv->plugins);
          manager->priv->plugins = NULL;
 }
@@ -336,7 +343,11 @@ gnome_settings_manager_start (GnomeSettingsManager *manager,
                 goto out;
         }
 
+        gnome_settings_profile_start ("initializing plugins");
+        manager->priv->settings = g_settings_new (DEFAULT_SETTINGS_PREFIX ".plugins");
+
         _load_all (manager);
+        gnome_settings_profile_end ("initializing plugins");
 
         ret = TRUE;
  out:
@@ -345,16 +356,6 @@ gnome_settings_manager_start (GnomeSettingsManager *manager,
         return ret;
 }
 
-gboolean
-gnome_settings_manager_start_with_settings_prefix (GnomeSettingsManager *manager,
-                                                   const char           *settings_prefix,
-                                                   GError              **error)
-{
-        g_object_set (manager, "settings-prefix", settings_prefix, NULL);
-
-        return gnome_settings_manager_start (manager, error);
-}
-
 void
 gnome_settings_manager_stop (GnomeSettingsManager *manager)
 {
@@ -370,54 +371,9 @@ gnome_settings_manager_stop (GnomeSettingsManager *manager)
 #endif
 
         _unload_all (manager);
-}
 
-static void
-_set_settings_prefix (GnomeSettingsManager *self,
-                   const char           *prefix)
-{
-        g_free (self->priv->settings_prefix);
-        self->priv->settings_prefix = g_strdup (prefix);
-}
-
-static void
-gnome_settings_manager_set_property (GObject        *object,
-                                     guint           prop_id,
-                                     const GValue   *value,
-                                     GParamSpec     *pspec)
-{
-        GnomeSettingsManager *self;
-
-        self = GNOME_SETTINGS_MANAGER (object);
-
-        switch (prop_id) {
-        case PROP_SETTINGS_PREFIX:
-                _set_settings_prefix (self, g_value_get_string (value));
-                break;
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gnome_settings_manager_get_property (GObject        *object,
-                                     guint           prop_id,
-                                     GValue         *value,
-                                     GParamSpec     *pspec)
-{
-        GnomeSettingsManager *self;
-
-        self = GNOME_SETTINGS_MANAGER (object);
-
-        switch (prop_id) {
-        case PROP_SETTINGS_PREFIX:
-                g_value_set_string (value, self->priv->settings_prefix);
-                break;
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
+        g_object_unref (manager->priv->settings);
+        manager->priv->settings = NULL;
 }
 
 static GObject *
@@ -454,8 +410,6 @@ gnome_settings_manager_class_init (GnomeSettingsManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = gnome_settings_manager_get_property;
-        object_class->set_property = gnome_settings_manager_set_property;
         object_class->constructor = gnome_settings_manager_constructor;
         object_class->dispose = gnome_settings_manager_dispose;
         object_class->finalize = gnome_settings_manager_finalize;
@@ -481,14 +435,6 @@ gnome_settings_manager_class_init (GnomeSettingsManagerClass *klass)
                               G_TYPE_NONE,
                               1, G_TYPE_STRING);
 
-        g_object_class_install_property (object_class,
-                                         PROP_SETTINGS_PREFIX,
-                                         g_param_spec_string ("settings-prefix",
-                                                              "settings-prefix",
-                                                              "settings-prefix",
-                                                              DEFAULT_SETTINGS_PREFIX,
-                                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-
         g_type_class_add_private (klass, sizeof (GnomeSettingsManagerPrivate));
 
         dbus_g_object_type_install_info (GNOME_TYPE_SETTINGS_MANAGER, &dbus_glib_gnome_settings_manager_object_info);
@@ -513,8 +459,6 @@ gnome_settings_manager_finalize (GObject *object)
 
         g_return_if_fail (manager->priv != NULL);
 
-        g_free (manager->priv->settings_prefix);
-
         G_OBJECT_CLASS (gnome_settings_manager_parent_class)->finalize (object);
 }
 
